==> politicsnlp-0.0.17.tar.gz: politicsnlp-0.0.17/README.md <==
# Python Narrative packages
- [politicsnlp](https://pypi.org/project/politicsnlp/) for Politics
- [religionnlp](https://pypi.org/project/religionnlp/) for Religion
- [lawnlp](https://pypi.org/project/lawnlp/) for Law
- [economynlp](https://pypi.org/project/economynlp/) for Economy
- [cpanlp](https://pypi.org/project/cpanlp/) for Business
- [militarynlp](https://pypi.org/project/militarynlp/) for Military

## Communicate in Politics like 🤖️
 <img src="https://raw.githubusercontent.com/python-narrative/politicsnlp/main/politics.jpg" width = "220" height = "100" alt="logo" align=center />

<br/>

[![PyPI - Python Version](https://img.shields.io/static/v1?label=pypi&message=v0.0.16&color=blue)](https://pypi.org/project/politicsnlp/)
[![Downloads](https://static.pepy.tech/badge/politicsnlp/week)](https://pepy.tech/project/politicsnlp)

For detailed installation instructions, see the
[documentation](https://cpanlp.com/documentation).

```python
pip install politicsnlp
import politicsnlp as poli
```


## Module:
|  Module   | Content  |
|  :----:  | :----:  |
| **Core**  | `Democracy`，`Freedom`，`Justice`，`Spirit Of The Law`，`Natural Rights`，`Separation Of Powers`|
| **Form Of Government**  | `Aristocracy`，`Autocracy`，`Colonialism`，`Communism`，`Direct Democracy`，`Monarchy`，`Oligarchy`，`Representative Democracy`，`Socialism`，`Theocracy`|
| **Ideology**  | `Confucianism`，`Nationalism`|
| **Individual**  | `Civil Servant`，`Monarch`，`Strongman`，`Tyrant`|
| **Institutions**  | `Administration`，`Judiciary`，`Legislature`|
| **Marxism**  | `Marxism`，`Mao Zedong Thought`，`Deng Xiaoping Theory`，`Xi Jinping Thought`|
| **Party**  | `Conservative Party`，`CCP`，`UKIP`|
| **Stance**  | `Hawk`，`Leftist`，`Rightist`，`Neutral`|




Check out: https://cpanlp.com

==> politicsnlp-0.0.19.tar.gz: politicsnlp-0.0.19/README.md <==


## Python Narrative Politics
 <img src="https://raw.githubusercontent.com/python-narrative/politicsnlp/main/politics.jpg" width = "220" height = "100" alt="logo" align=center />

<br/>

[![PyPI - Python Version](https://img.shields.io/static/v1?label=pypi&message=v0.0.16&color=blue)](https://pypi.org/project/politicsnlp/)
[![Downloads](https://static.pepy.tech/badge/politicsnlp/week)](https://pepy.tech/project/politicsnlp)

For detailed installation instructions, see the
[documentation](https://cpanlp.com/documentation).

```python
pip install politicsnlp
import politicsnlp as poli
```


## Module:
|  Module   | Content  |
|  :----:  | :----:  |
| **Core**  | `Democracy`，`Freed|
| **Diplomacy**  | `Coercive Diplomacy`，`Hegemony`，`Wolf WarriorDiplomacy`|
| **Form Of Government**  | `Aristocracy`，`Autocracy`，`Colonialism`|
| **Ideology**  | `Confucianism`，`Nationalism`|
| **Individual**  | `Civil Servant`，`Monarch`，`Strongman`，`Tyrant`|
| **Institutions**  | `Administration`，`Judiciary`，`Legislature`|
| **Marxism**  | `Marxism`，`Mao Zedong Thought`，`Deng Xiaoping Theory`，`Xi Jinping Thought`|
| **Organisation**  | `Nato`|
| **Party**  | `Conservative Party`，`CCP`，`UKIP`|
| **People**  | `Crowd`，`Refugee`，`RedGeneration`|
| **Power**  | `Discourse Power`|
| **Stance**  | `Hawk`，`Leftist`，`Rightist`，`Neutral`|
| **Uprisings_Protests**  | `Arab Spring`，`Blank Revolution`，`Jasmine Revolution`|


## Python Narrative packages
- [politicsnlp](https://pypi.org/project/politicsnlp/) for Politics
- [religionnlp](https://pypi.org/project/religionnlp/) for Religion
- [lawnlp](https://pypi.org/project/lawnlp/) for Law
- [economynlp](https://pypi.org/project/economynlp/) 
for Economy
- [cpanlp](https://pypi.org/project/cpanlp/) for 
Business
- [militarynlp](https://pypi.org/project/militarynlp/) for Military

Check out: https://cpanlp.com
